==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/ComputeProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes the compute profile.
 * @property roles The list of roles in the cluster.
 */
public data class ComputeProfileArgs(
    public val roles: Output<List<RoleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs =
        com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs.builder()
            .roles(
                roles?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ComputeProfileArgs].
 */
@PulumiTagMarker
public class ComputeProfileArgsBuilder internal constructor() {
    private var roles: Output<List<RoleArgs>>? = null

    /**
     * @param value The list of roles in the cluster.
     */
    @JvmName("mgvegpbsdohhskjk")
    public suspend fun roles(`value`: Output<List<RoleArgs>>) {
        this.roles = value
    }

    @JvmName("cajwumbvcltiaecs")
    public suspend fun roles(vararg values: Output<RoleArgs>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values The list of roles in the cluster.
     */
    @JvmName("lfspgipgmttdvbic")
    public suspend fun roles(values: List<Output<RoleArgs>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value The list of roles in the cluster.
     */
    @JvmName("xkgmuwnswbqaipwr")
    public suspend fun roles(`value`: List<RoleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param argument The list of roles in the cluster.
     */
    @JvmName("tolupnvsopqcqmkr")
    public suspend fun roles(argument: List<suspend RoleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { RoleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.roles = mapped
    }

    /**
     * @param argument The list of roles in the cluster.
     */
    @JvmName("hdxvvbpyvdihkuue")
    public suspend fun roles(vararg argument: suspend RoleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { RoleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.roles = mapped
    }

    /**
     * @param argument The list of roles in the cluster.
     */
    @JvmName("seeqvfwjcajmcyds")
    public suspend fun roles(argument: suspend RoleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RoleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.roles = mapped
    }

    /**
     * @param values The list of roles in the cluster.
     */
    @JvmName("lmgnjbtkncjpcrok")
    public suspend fun roles(vararg values: RoleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    internal fun build(): ComputeProfileArgs = ComputeProfileArgs(
        roles = roles,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/ComputeProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes the compute profile.
 * @property roles The list of roles in the cluster.
 */
public data class ComputeProfileArgs(
    public val roles: Output<List<RoleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs =
        com.pulumi.azurenative.hdinsight.inputs.ComputeProfileArgs.builder()
            .roles(
                roles?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ComputeProfileArgs].
 */
@PulumiTagMarker
public class ComputeProfileArgsBuilder internal constructor() {
    private var roles: Output<List<RoleArgs>>? = null

    /**
     * @param value The list of roles in the cluster.
     */
    @JvmName("syetrhxsnexiokht")
    public suspend fun roles(`value`: Output<List<RoleArgs>>) {
        this.roles = value
    }

    @JvmName("afhtsxbhkdehysca")
    public suspend fun roles(vararg values: Output<RoleArgs>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values The list of roles in the cluster.
     */
    @JvmName("ipgtxbpteqdpigqc")
    public suspend fun roles(values: List<Output<RoleArgs>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value The list of roles in the cluster.
     */
    @JvmName("ckoisscottjhibtd")
    public suspend fun roles(`value`: List<RoleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param argument The list of roles in the cluster.
     */
    @JvmName("cniuqjatiqqnvipl")
    public suspend fun roles(argument: List<suspend RoleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { RoleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.roles = mapped
    }

    /**
     * @param argument The list of roles in the cluster.
     */
    @JvmName("tybwwioehxysdjei")
    public suspend fun roles(vararg argument: suspend RoleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { RoleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.roles = mapped
    }

    /**
     * @param argument The list of roles in the cluster.
     */
    @JvmName("poqbvuqlovnkpnop")
    public suspend fun roles(argument: suspend RoleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RoleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.roles = mapped
    }

    /**
     * @param values The list of roles in the cluster.
     */
    @JvmName("ihfhkxlbagpqspip")
    public suspend fun roles(vararg values: RoleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    internal fun build(): ComputeProfileArgs = ComputeProfileArgs(
        roles = roles,
    )
}
